@@ -1,4 +1,4 @@
-from robotpy_toolkit_7407.unum import Unum
+from fast_unit import Unum
 
 
 class Motor:
