@@ -1,4 +1,4 @@
-from unum import Unum
+from fast_unit import Unum
 from wpilib import ADIS16448_IMU
 
 from robotpy_toolkit_7407.utils.units import deg
